@@ -6,11 +6,15 @@
 #include <string.h>
 #include <mate-panel-applet.h>
 #include <mate-panel-applet-gsettings.h>
-#ifdef HAVE_MUCHARMAP
-#	include <mucharmap/mucharmap.h>
+#ifdef HAVE_GUCHARMAP
+#include <gucharmap/gucharmap.h>
 #endif
 #include "charpick.h"
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define GTK_OBJECT(x) G_OBJECT(x)
+#endif
+
 /* The comment for each char list has the html entity names of the chars */
 /* All gunicar codes should end in 0 */
 
@@ -325,8 +329,12 @@ get_menu_pos (GtkMenu *menu, gint *x, gint *y, gboolean *push_in, gpointer data)
 	
 	gtk_widget_size_request (GTK_WIDGET (menu), &reqmenu);
 	gdk_window_get_origin (GDK_WINDOW (gtk_widget_get_window(curr_data->applet)), &tempx, &tempy);
-     	gdk_window_get_geometry (GDK_WINDOW (gtk_widget_get_window(curr_data->applet)), NULL, NULL,
-     				 &width, &height, NULL);
+	gdk_window_get_geometry (GDK_WINDOW (gtk_widget_get_window(curr_data->applet)), NULL, NULL,
+				 &width, &height
+#if !GTK_CHECK_VERSION (3, 0, 0)
+				 , NULL
+#endif
+				 );
      			      
      	switch (mate_panel_applet_get_orient (MATE_PANEL_APPLET (curr_data->applet))) {
      	case MATE_PANEL_APPLET_ORIENT_DOWN:
@@ -457,13 +465,13 @@ build_table(charpick_data *p_curr_data)
     g_utf8_strncpy (label, charlist, 1);
     charlist = g_utf8_next_char (charlist);
 
-#ifdef HAVE_MUCHARMAP
+#ifdef HAVE_GUCHARMAP
     /* TRANSLATOR: This sentance reads something like 'Insert "PILCROW SIGN"'
      *             hopefully, the name of the unicode character has already
      *             been translated.
      */
     name = g_strdup_printf (_("Insert \"%s\""),
-		    mucharmap_get_unicode_name (g_utf8_get_char (label)));
+		    gucharmap_get_unicode_name (g_utf8_get_char (label)));
 #else
     name = g_strdup (_("Insert special character"));
 #endif
@@ -602,7 +610,7 @@ help_cb (GtkAction     *action,
   GError *error = NULL;
 
   gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (curr_data->applet)),
-                "ghelp:char-palette",
+                "help:mate-char-palette",
                 gtk_get_current_event_time (),
                 &error);
 
